@@ -40,11 +40,13 @@ class SystemModel : public AbstractModel
 
         Q_INVOKABLE bool trigger(int row, const QString &actionId, const QVariant &argument);
 
-        AbstractModel* favoritesModel();
+    protected Q_SLOTS:
+        virtual void refresh();
 
     private:
+        void init();
+
         QList<SystemEntry *> m_entryList;
-        AbstractModel *m_favoritesModel;
 };
 
 #endif
